====
Lena
====

Lena is an architectural framework for data analysis. It is written in Python and works with Python versions 2, 3 and PyPy.

For more information on the framework and its installation see the documentation at https://lena.readthedocs.io 
